@@ -155,9 +155,10 @@ gboolean wnck_window_is_maximized              (WnckWindow *window);
 gboolean wnck_window_is_shaded                 (WnckWindow *window);
 gboolean wnck_window_is_skip_pager             (WnckWindow *window);
 gboolean wnck_window_is_skip_tasklist          (WnckWindow *window);
-gboolean wnck_window_is_fullscreen                 (WnckWindow *window);
+gboolean wnck_window_is_fullscreen             (WnckWindow *window);
 gboolean wnck_window_is_sticky                 (WnckWindow *window);
 gboolean wnck_window_demands_attention         (WnckWindow *window);
+gboolean wnck_window_or_transient_demands_attention (WnckWindow *window);
 
 void wnck_window_set_skip_pager    (WnckWindow *window,
                                     gboolean skip);
@@ -167,9 +168,10 @@ void wnck_window_set_fullscreen (WnckWindow *window,
                                  gboolean fullscreen);
 
 void wnck_window_close                   (WnckWindow *window,
-					  guint32     timestamp);
+                                          guint32     timestamp);
 void wnck_window_minimize                (WnckWindow *window);
-void wnck_window_unminimize              (WnckWindow *window);
+void wnck_window_unminimize              (WnckWindow *window,
+                                          guint32     timestamp);
 void wnck_window_maximize                (WnckWindow *window);
 void wnck_window_unmaximize              (WnckWindow *window);
 void wnck_window_maximize_horizontally   (WnckWindow *window);
@@ -192,10 +194,12 @@ gboolean wnck_window_is_pinned (WnckWindow *window);
 void     wnck_window_pin       (WnckWindow *window);
 void     wnck_window_unpin     (WnckWindow *window);
 
-void     wnck_window_activate  (WnckWindow *window);
+void     wnck_window_activate  (WnckWindow *window,
+                                guint32     timestamp);
 gboolean wnck_window_is_active (WnckWindow *window);
 gboolean wnck_window_is_most_recently_activated (WnckWindow *window);
-void     wnck_window_activate_transient (WnckWindow *window);
+void     wnck_window_activate_transient (WnckWindow *window,
+                                         guint32     timestamp);
 gboolean wnck_window_transient_is_active (WnckWindow *window);
 
 GdkPixbuf* wnck_window_get_icon      (WnckWindow *window);
